##  Identify Applications
First, you filter your inventory to show the applications in your scope. Then, you save the search results so you can quickly re-access the scoped applications anytime.
  1. Filter your inventory for application fact sheets. Click on Application in the type section in the left panel. The quick filters give you an easy way to navigate your inventory and visualize exactly the data you need.
  2. Filter the applications based on their lifecycle. Select the lifecycle stage Active in the left panel.
  3. Click on the lifecycle tag at the top of your search results. Select point in time from the dropdown menu and choose End-of-year. Narrowing down the list to applications that will remain active after the end of the year focuses your rationalization activities on relevant apps.
  4. Go to the Business Capabilities filters in the left panel and select a level 1 business capability, for example, HR. Focusing on one or two business capabilities makes the rationalization initiative more manageable.
![Screenshot of the inventory showing how to filter for business capabilities](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio54d7190f2a9940bcb9fb61e6cc89d556_HiRes.png)
